🪵 Logtail Integration For Python

[![ISC License](https://img.shields.io/badge/license-ISC-ff69b4.svg)](LICENSE.md)
![Logtail python client](https://github.com/logtail/logtail-python/actions/workflows/main.yml/badge.svg?branch=master)

This repository contains the [Logtail](https://logtail.com) Python library, turning your application logs into rich structured events.

---

### Features

* Simple integration. Integrates with the Python `logging` library.
* Support for structured logging and events.
* Automatically captures useful context.
* Performant, light weight, with a thoughtful design.
